# BEGIN COPYRIGHT BLOCK
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
# (C) 2007 Red Hat, Inc.
# All rights reserved.
# END COPYRIGHT BLOCK

###############################################################################
###                          D E F I N I T I O N S                          ###
###############################################################################

## Entity Definitions
%define base_entity       Red hat
%define base_flavor       redhat
%define base_prefix       pki

## Product Definitions
%define base_system       Certificate System
%define base_product      Registration Authority
%define base_component    ra
%define base_pki          %{base_entity} %{base_system}

## Package Header Definitions
%define base_name         %{base_prefix}-%{base_component}
%define base_version      8.1.0
%define base_release      8
%define base_phase        %{nil}
%define base_group        System Environment/Daemons
%define base_vendor       Red Hat, Inc.
%define base_license      GPLv2 with exceptions
%define base_packager     %{base_vendor} <http://bugzilla.redhat.com/bugzilla>
%define base_summary      %{base_pki} - %{base_product}
%define base_url          http://www.redhat.com/certificate_system

## Legacy Definitions
%define legacy_prefix     rhpki
%define legacy_name       %{legacy_prefix}-%{base_component}

## Pre & Post Install/Uninstall Scripts Definitions
%define base_user         pkiuser
%define base_uid          17
%define base_gid          17
%define base_instance     /var/lib/%{base_name}

## Helper Definitions
%define pki_ca            %{base_entity} Certificate Authority
%define pki_drm           %{base_entity} Data Recovery Manager
%define pki_ds            %{base_entity} Directory Server
%define pki_ocsp          %{base_entity} Online Certificate Status Protocol Manager
%define pki_ra            %{base_entity} Registration Authority
%define pki_tks           %{base_entity} Token Key Service
%define pki_tps           %{base_entity} Token Processing System

## Don't build the debug packages
%define debug_package     %{nil}


##===================##
## Linux Definitions ##
##===================##
%ifos Linux
## Disallow an initial login shell
## NOTE:  SELinux policy requires a shell of /sbin/nologin
%define base_login_shell  /sbin/nologin

## For PKI version information, ALWAYS refer to the version of the
## Red Hat UI package dependency associated with this Red Hat spec file!
%define pki_version       %(echo `rpm -q --queryformat '%{VERSION}' %{base_flavor}-%{base_name}-ui`)

## A distribution model is required on certain Linux operating systems!
##
## check for a pre-defined distribution model
%define undefined_distro  %(test "%{dist}" = "" && echo 1 || echo 0)
%if %{undefined_distro}
%define is_fedora         %(test -e /etc/fedora-release && echo 1 || echo 0)
%if %{is_fedora}
## define a default distribution model on Fedora Linux
%define dist_prefix       .fc
%define dist_version      %(echo `rpm -qf --qf='%{VERSION}' /etc/fedora-release` | tr -d [A-Za-z])
%define dist              %{dist_prefix}%{dist_version}
%else
%define is_redhat         %(test -e /etc/redhat-release && echo 1 || echo 0)
%if %{is_redhat}
## define a default distribution model on Red Hat Linux
%define dist_prefix       .el
%define dist_version      %(echo `rpm -qf --qf='%{VERSION}' /etc/redhat-release` | tr -d [A-Za-z])
%define dist              %{dist_prefix}%{dist_version}
%endif
%endif
%endif
%endif



###############################################################################
###                       P A C K A G E   H E A D E R                       ###
###############################################################################

Name:           %{base_name}
Version:        %{base_version}
Release:        %{base_release}%{?base_phase}%{?dist}
Summary:        %{base_summary}
Vendor:         %{base_vendor}
URL:            %{base_url}
License:        %{base_license}
Packager:       %{base_packager}
Group:          %{base_group}


## Without AutoReqProv: no, rpmbuild finds all sorts of crazy
## dependencies that we don't care about, and refuses to install
AutoReqProv:    no

BuildArch:      noarch
BuildRoot:      %{_builddir}/%{base_name}-root


## NOTE:  This spec file may require a specific JDK, "gcc", and/or "gcc-c++"
##        packages as well as the "rpm" and "rpm-build" packages.
##
##        Technically, "ant" should not need to be in "BuildRequires" since
##        it is the Java equivalent of "make" (and/or "Autotools").
##
BuildRequires:  ant >= 1.6.5, %{base_flavor}-%{base_name}-ui >= 8.1.0

## Without Requires something, rpmbuild will abort!
Requires:       %{base_name}-ui, %{base_prefix}-setup >= 8.1.0, mod_nss >= 1.0.8, mod_perl >= 2.0.4, mod_revocator >= 1.0.3, mozldap >= 6.0.5, perl-DBD-SQLite, perl-DBI, perl-HTML-Parser, perl-HTML-Tagset, perl-Parse-RecDescent, perl-URI, perl-XML-NamespaceSupport, perl-XML-Parser, /usr/sbin/sendmail, sqlite >= 3.3.6, %{base_prefix}-selinux >= 8.1.0, perl-XML-Simple
Provides:       %{legacy_name}
Obsoletes:      %{legacy_name}


## This package is non-relocatable!
#Prefix:

Source0:        %{base_name}-%{base_version}.tar.gz

## This package currently contains no patches!
#Patch0:


%description
%{base_pki} is an enterprise software system designed
to manage enterprise Public Key Infrastructure (PKI) deployments.

The %{pki_ra} is an optional PKI subsystem that
acts as a front-end for authenticating and processing
enrollment requests, PIN reset requests, and formatting requests.

%{pki_ra} communicates over SSL with the
%{pki_ca} to fulfill the user's requests.



###############################################################################
###                  P R E P A R A T I O N   &   S E T U P                  ###
###############################################################################

## On Linux systems, prep and setup expect there to be a Source file
## in the /usr/src/redhat/SOURCES directory - it will be unpacked
## in the _builddir (not BuildRoot)
%prep


%setup -q


## This package currently contains no patches!
#%patch0
# patches



###############################################################################
###                        B U I L D   P R O C E S S                        ###
###############################################################################

%build
ant -Dspecfile=%{base_name}.spec



###############################################################################
###                 I N S T A L L A T I O N   P R O C E S S                 ###
###############################################################################

%install
cd dist/binary
unzip %{name}-%{version}.zip -d ${RPM_BUILD_ROOT}
sed -i 's/^preop.product.version=.*$/preop.product.version=%{pki_version}/' ${RPM_BUILD_ROOT}/usr/share/%{base_prefix}/%{base_component}/conf/CS.cfg



###############################################################################
###                      C L E A N U P   P R O C E S S                      ###
###############################################################################

%clean
rm -rf ${RPM_BUILD_ROOT}



###############################################################################
###  P R E  &  P O S T   I N S T A L L / U N I N S T A L L   S C R I P T S  ###
###############################################################################

%pre
if [ `grep -c %{base_user} /etc/group` -eq 0 ] ; then
	echo "Adding default PKI group \"%{base_user}\" (gid=%{base_gid}) to /etc/group."
	groupadd -g %{base_gid} -r %{base_user}
	if [ $? -ne 0 ]; then
		echo "Adding default PKI group \"%{base_user}\" (gid=random) to /etc/group."
		groupadd %{base_user}
	fi
fi
if [ `grep -c %{base_user} /etc/passwd` -eq 0 ] ; then
	echo "Adding default PKI user \"%{base_user}\" (uid=%{base_uid}) to /etc/passwd."
	useradd -g %{base_user} -d %{_datadir}/%{base_prefix} -s %{base_login_shell} -c "%{base_pki}" -u %{base_uid} -r -m %{base_user}
	if [ $? -ne 0 ]; then
		echo "Adding default PKI user \"%{base_user}\" (uid=random) to /etc/passwd."
		useradd -g %{base_user} -d %{_datadir}/%{base_prefix} -s %{base_login_shell} -c "%{base_pki}" -m %{base_user}
	fi
fi
if [ "$1" -gt 1 ]; then
    backup_dir="%{_datadir}/%{base_prefix}/`rpm -q pki-ra|cut -c5-`"
    if [ -e $backup_dir ]; then
        rm -rf $backup_dir
    fi

    cp -rf %{_datadir}/%{base_prefix}/%{base_component}  $backup_dir
fi




## This package currently contains no post-installation process!
#%post


%preun
if [ -d %{base_instance} ] ; then
	echo "WARNING:  The default instance \"%{base_instance}\" was NOT removed!"
	echo ""
	echo "NOTE:  This means that the data in the default instance called"
	echo "       \"%{base_instance}\" will NOT be overwritten once the"
	echo "       \"%{name}\" package is re-installed."
	echo ""
	echo "Shutting down the default instance \"%{base_instance}\""
	echo "PRIOR to uninstalling the \"%{name}\" package:"
	echo ""
	/etc/init.d/%{base_name} stop
fi


## This package currently contains no post-uninstallation process!
#%postun



###############################################################################
###   I N V E N T O R Y   O F   F I L E S   A N D   D I R E C T O R I E S   ### 
###############################################################################

%files
%attr(-,root,root)     %{_datadir}/doc/%{base_name}-%{base_version}/*
%attr(-,root,root)     %{_datadir}/%{base_prefix}/%{base_component}/alias
%attr(00660,root,root) %{_datadir}/%{base_prefix}/%{base_component}/conf/CS.cfg
%attr(-,root,root)     %{_datadir}/%{base_prefix}/%{base_component}/conf/[a-z]*
%attr(-,root,root)     %{_datadir}/%{base_prefix}/%{base_component}/docroot
%attr(-,root,root)     %{_datadir}/%{base_prefix}/%{base_component}/etc
%attr(-,root,root)     %{_datadir}/%{base_prefix}/%{base_component}/lib
%attr(-,root,root)     %{_datadir}/%{base_prefix}/%{base_component}/logs
%attr(-,root,root)     %{_datadir}/%{base_prefix}/%{base_component}/scripts
%attr(-,root,root)     %{_datadir}/%{base_prefix}/%{base_component}/setup



###############################################################################
###                            C H A N G E L O G                            ###
###############################################################################

%changelog
* Mon May  4 2015 Matthew Harmsen <mharmsen@redhat.com> 8.1.0-8
- Bump release number to build RHCS 8.1.6

* Thu Aug 25 2011 Ade Lee <alee@redhat.com> 8.1.0-7
- Bugzilla Bug #733065 - User enrollment with RA -- this fails with
  CA Connection Error 

* Wed Jul 6 2011 Ade Lee <alee@redhat.com> 8.1.0-6
- Bugzilla Bug #717765 - TPS configuration: logging into security domain
  from tps does not work with clientauth=want

* Mon Apr 25 2011 Ade Lee <alee@redhat.com> 8.1.0-5
- Bugzilla Bug #699364 - PKI-RA instance not created successfully

* Fri Apr 15 2011 Ade Lee <alee@redhat.com> 8.1.0-4
- Bugzilla Bug #694569 - parameter used by pkiremove not updated

* Thu Mar 24 2011 Matthew Harmsen <mharmsen@redhat.com> 8.1.0-3
- Bugzilla Bug #690646 - Update Build and Runtime Dependencies for RHCS 8.1

* Wed Jan 26 2011 Matthew Harmsen <mharmsen@redhat.com> 8.1.0-2
- Bugzilla Bug #588460 - Add new 'mod_revocator' runtime dependency to RA and
  TPS . . .

* Tue Jan 12 2010 Matthew Harmsen <mharmsen@redhat.com> 8.1.0-1
- Bump to version 8.1.0

* Tue Jul 14 2009 Ade Lee <alee@redhat.com> 8.0.0-26
- Bugzilla Bug #511337 - sscep getca fails with define CA identifier 
- Release Candidate 4a build

* Mon Jul 13 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-25
- Bugzilla Bug #511136 -  Integrate EULA file into RHCS
- Release Candidate 4 build

* Wed Jul 8 2009 Kevin Wright <kwright@redhat.com> 8.0.0-24
- Bugzilla Bug #510352 -  Release Candidate 3 build

* Thu Jul 2 2009 Kevin Wright <kwright@redhat.com> 8.0.0-23
- Bugzilla Bug #509447 -  Release Candidate 2 build

* Thu Jun 25 2009 Kevin Wright <kwright@redhat.com> 8.0.0-22
- Bugzilla Bug #508179 -  Remove base_phase ".beta" tag

* Fri Jun 19 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-21
- Bugzilla Bug #506867 -  Provide custom error page for HTTP STATUS 500

* Mon Jun 15 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-20
- Bugzilla Bug #502908 -  Current page not found handling is a Cat 2 finding
  with the Tomcat STIG

* Mon Jun 8 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-19
- Bugzilla Bug #501081 -  remove mod_revocator rpm as a dependency

* Sat May 30 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-18
- Bugzilla Bug #476782 -  Create "pkiuser" with a predetermined
  system "UID" and "GID" . . .

* Mon May 4 2009 Kevin Wright <kwright@redhat.com> 8.0.0-17
- Bugzilla Bug #499030 -  Beta 2 Release

* Thu Apr 16 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-16
- Bugzilla Bug #495959 -  pkiremove requires "perl-XML-SAX" as a runtime
  dependency

* Sat Mar 28 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-15
- Bugzilla Bug #492180 -  Security officer: token recovery for a security
  officer throws error 28 'connection to server lost'.
- Bugzilla Bug #492503 -  Integrate "mod_revocator" as a runtime dependency
  for RA and TPS  

* Fri Mar 27 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-14
- Bugzilla Bug #492502 -  Redefine "base_phase" from ".alpha" to ".beta"

* Wed Mar 11 2009 Ade Lee <alee@redhat.com> 8.0.0-13
  Bugzilla Bug #489712 RA and TPS need perl-XML-Simple as prereq

* Fri Mar 6 2009 Ade Lee <alee@redhat.com> 8.0.0-12
- Bugzilla Bug 472308 - web installer display wrong product version in first Welcome panel

* Sat Feb 28 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-11
- Bugzilla Bug #487896 - Introduce optional 'base_phase' release tag to
  denote ".alpha", ".beta", etc.

* Sat Feb 14 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-10
- Bugzilla Bug #250874 -Change spec file dependencies to rely on latest
  versions of components (NSPR, NSS, JSS, MOD_NSS)

* Tue Jan 27 2009 Ade Lee <alee@redhat.com> 8.0.0-9
- Bugzilla Bug 480679 - Integrate selinux into framework

* Thu Jan 22 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-8
- Bugzilla Bug #480952 - moved "perl-XML-Simple" and "perl-libwww-perl"
  runtime dependencies to pki-setup
- Bugzilla Bug #480515 -  lowered "perl-DBI" version runtime dependency

* Sat Jan 17 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-7
- Bugzilla Bug #480104 -  RA configuraiton wizard url fails to start

* Wed Dec 10 2008 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-6
- Bugzilla Bug #475895 - Parameterize the initial login shell

* Sat Nov 29 2008 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-5
- Aligned RHEL 5, RHEL 4, and Solaris 9 "base_release" numbers
- Bugzilla Bug #445402 - Changed "base_url" from
                         "http://www.redhat.com/software/rha/certificate" to
                         "http://www.redhat.com/certificate_system"

* Sat Nov 22 2008 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-4
- Bugzilla Bug #472305 - "equality" tests in all spec files need to be fixed
- Bumped "java" and "java-devel" 1.4.2 and 1.5.0 dependencies to 1.6.0
- Changed "java-sdk" to "java-devel" for consistency

* Fri Jun 8 2007 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-3
- bugzilla bug #243480 - added legacy upgrade path

* Tue Jun 5 2007 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-2
- bugzilla bug #242575 - Made numerous changes to spec file.

* Mon May 21 2007 Kevin McCarthy <kmccarth@redhat.com> 8.0.0-1
- Bump to version 8.0.

* Fri May 04 2007 Kevin McCarthy <kmccarth@redhat.com> 7.3.0-62
- Fix for RHEL5.

* Sat Apr 21 2007 Matthew Harmsen <mharmsen@redhat.com> 7.3.0-61
- bugzilla #235464 - place LICENSE into /usr/share/doc/rhpki-ra-7.3.0/

* Thu Apr 19 2007 Thomas Kwan <nkwan@redhat.com> 7.3.0-60
- bugzilla #237196 - pin is incorrectly printed out to the end user

* Thu Apr 19 2007 Thomas Kwan <nkwan@redhat.com> 7.3.0-59
- bugzilla #237195 - support new footer and header

* Thu Apr 19 2007 Thomas Kwan <nkwan@redhat.com> 7.3.0-58
- bugzilla #237161 - read request from database before calling plugins

* Thu Apr 19 2007 Thomas Kwan <nkwan@redhat.com> 7.3.0-57
- bugzilla #237059 - changed license to GPL

* Thu Apr 19 2007 Thomas Kwan <nkwan@redhat.com> 7.3.0-56
- bugzilla #237057 - fixed paging in list request

* Wed Apr 18 2007 Thomas Kwan <nkwan@redhat.com> 7.3.0-55
- bugzilla #237048 - fixed invalid request status problem

* Wed Apr 18 2007 Thomas Kwan <nkwan@redhat.com> 7.3.0-55
- bugzilla #237048 - fixed invalid request status problem

* Wed Apr 18 2007 Thomas Kwan <nkwan@redhat.com> 7.3.0-54
- bugzilla #237029 - ignored empty mailTo in Cs.cfg
- redirected user to separate error page for agent enrollment

* Wed Apr 18 2007 Thomas Kwan <nkwan@redhat.com> 7.3.0-53
- bugzilla #237022 - supported IE in renewal operation

* Wed Apr 18 2007 Thomas Kwan <nkwan@redhat.com> 7.3.0-52
- bugzilla #236861 - added border to the approval page

* Tue Apr 17 2007 Thomas Kwan <nkwan@redhat.com> 7.3.0-51
- bugzilla #236859 - fixed revocation error

* Tue Apr 17 2007 Thomas Kwan <nkwan@redhat.com> 7.3.0-50
- bugzilla #236851 - fixed core dump on approval of failed request
- bugzilla #236780 - displayed error if input in invalid in agent certificate enrollment page
- bugzilla #236852 - error.cgi called the wrong function
- bugzilla #236853 - Removed hardcoded subject name for IE enrollment

* Thu Apr 5 2007 Thomas Kwan <nkwan@redhat.com> 7.3.0-48
- Included LICENSE file

* Thu Apr 5 2007 Thomas Kwan <nkwan@redhat.com> 7.3.0-47
- Fixed problem in showing all requests

* Wed Apr 4 2007 Thomas Kwan <nkwan@redhat.com> 7.3.0-46
- Made tmp filename unique

* Tue Apr 3 2007 Thomas Kwan <nkwan@redhat.com> 7.3.0-45
- Added benchmark code

* Tue Apr 3 2007 Thomas Kwan <nkwan@redhat.com> 7.3.0-44
- Removed code to lock the database

* Tue Apr 3 2007 Thomas Kwan <nkwan@redhat.com> 7.3.0-43
- Kept the critical section as small as possible

* Mon Apr 2 2007 Thomas Kwan <nkwan@redhat.com> 7.3.0-42
- Increased DBD timeout value

* Fri Mar 30 2007 Thomas Kwan <nkwan@redhat.com> 7.3.0-41
- Added logic to redo the SQL statement if the database is blocked

* Thu Mar 29 2007 Thomas Kwan <nkwan@redhat.com> 7.3.0-40
- Added locking in perl Velocity implementation

* Thu Mar 29 2007 Matthew Harmsen <mharmsen@redhat.com> 7.3.0-39
- Bumped Release Number.

* Wed Mar 28 2007 Matthew Harmsen <mharmsen@redhat.com> 7.3.0-38
- Made package URL contingent upon distribution.
- Bumped Release Number.

* Mon Mar 19 2007 Thomas Kwan <nkwan@redhat.com> 7.3.0-35
- Fixed the sqlite corruption problem

* Mon Mar 19 2007 Thomas Kwan <nkwan@redhat.com> 7.3.0-34
- Fixed the error in handling csr_type

* Fri Mar 16 2007 Thomas Kwan <nkwan@redhat.com> 7.3.0-32
- Changed cellspacing to 1 from 10

* Fri Mar 16 2007 Thomas Kwan <nkwan@redhat.com> 7.3.0-31
- Added fortitude-mod_nss to Requires

* Thu Mar 15 2007 Thomas Kwan <nkwan@redhat.com> 7.3.0-30
- Fixed branding issue

* Thu Mar 15 2007 Thomas Kwan <nkwan@redhat.com> 7.3.0-29
- Handled more enrollment type

* Wed Mar 14 2007 Thomas Kwan <nkwan@redhat.com> 7.3.0-28
- Lower requires to 3.3.3 for sqlite

* Fri Mar 9 2007 Thomas Kwan <nkwan@redhat.com> 7.3.0-27
- Generalized spec to handle el5 or later.

* Thu Mar 8 2007 Thomas Kwan <nkwan@redhat.com> 7.3.0-26
- Changed ra rpm to noarch

* Wed Jan 17 2007 Thomas Kwan <nkwan@redhat.com> 7.3.0-1
- Modified this so that it can be built in brew

* Wed Feb 22 2006 Matthew Harmsen <mharmsen@redhat.com> 7.3.0-1
- Renamed "rpm.template" to "pki.template". Filled in Solaris section.

* Mon Feb 20 2006 Matthew Harmsen <mharmsen@redhat.com> 7.3.0-1
- Separated template into Linux, Solaris, and Changelog sections.

* Mon Dec 5 2005 Matthew Harmsen <mharmsen@redhat.com> 7.3.0-1
- Initial RPM template.

